/*
 * Copyright 2004-2007 the Seasar Foundation and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.seasar.uruma.example.employee.action;

import java.util.List;

import org.eclipse.swt.widgets.Shell;
import org.seasar.uruma.annotation.ApplicationContext;
import org.seasar.uruma.annotation.EventListener;
import org.seasar.uruma.annotation.Form;
import org.seasar.uruma.annotation.InitializeMethod;
import org.seasar.uruma.example.employee.dto.DepartmentDto;
import org.seasar.uruma.example.employee.dto.EmployeeDto;
import org.seasar.uruma.example.employee.dxo.EmployeeEditFormDxo;
import org.seasar.uruma.example.employee.entity.Employee;
import org.seasar.uruma.example.employee.form.EmployeeEditForm;
import org.seasar.uruma.example.employee.logic.EmployeeLogic;

/**
 * 編集画面のためのアクションクラスです。<br />
 * 
 * @author bskuroneko
 * @author y-komori
 */
@Form(EmployeeEditForm.class)
public class EditAction {
	public EmployeeLogic employeeLogic;

	public EmployeeEditFormDxo employeeEditFormDxo;

	public Shell shell;

	public EmployeeEditForm employeeEditForm;

	@ApplicationContext
	public List<EmployeeDto> selectedEmployees;

	@ApplicationContext
	public boolean edited;

	@InitializeMethod
	public void initialize() {
		Employee employee = employeeLogic.getEmployee(selectedEmployees.get(0)
				.getEmpno());
		employeeEditFormDxo.convert(employee, employeeEditForm);
		employeeEditForm.setDeptList(employeeLogic.getAllDepartments());

		DepartmentDto selectedDepartment = new DepartmentDto();
		selectedDepartment.setDeptno(employeeEditForm.getDeptno());
		employeeEditForm.setSelectedDepartmentDto(selectedDepartment);
	}

	@EventListener(id = "ok")
	public void onOk() {
		DepartmentDto selectedDepartmentDto = employeeEditForm
				.getSelectedDepartmentDto();
		if (selectedDepartmentDto != null) {
			employeeEditForm.setDeptno(selectedDepartmentDto.getDeptno());
		}
		employeeEditFormDxo.convert(employeeEditForm, selectedEmployees.get(0));
		employeeLogic.update(selectedEmployees.get(0));
		edited = true;
		shell.close();
	}

	@EventListener(id = "cancel")
	public void onCancel() {
		shell.close();
	}
}
